import React, { useEffect, useState } from 'react'
import { Card, Form, Input, Button, Select, message } from 'antd'
import styles from './IotConfig.less'
import { GetIOTPlatformVersion, GetTCPConfigInfo, PingIOTPlatform, SaveTcpAddress } from '@/services/platform/hostmanager'
const layout = {
    labelCol: { span: 8 },
    wrapperCol: { span: 16 },

};
const tailLayout = {
    wrapperCol: { offset: 8, span: 16 },

};

const IotConfig = () => {


    const [currentIotVersion, setCurrentIotVersion] = useState({ data: "" });
    const [currentIotConfig, setCurrentIotConfig] = useState({
        TcpAddress: "",
        SSLSafe: "",
        IotAddress: ""
    });

    const [form] = Form.useForm();
    const onFinish = (values) => {
        if (values.IotAddress != null && values.IotAddress.length > 0) {
            PingIot({ ip: values.IotAddress, values: values })
        } else {
            SaveIotConfig({
                tcpAddress: values.TcpAddress,
                iotAddress: values.IotAddress,
                sslSafe: values.SSLSafe
            })
        }
    };

    const onFinishFailed = (errorInfo) => {
        console.log('Failed:', errorInfo);
    };

    useEffect(() => {
        GetCurentIotVerison()
        GetIotConfig()

    }, [])

    const GetCurentIotVerison = () => {
        GetIOTPlatformVersion().then(
            res => {
                if (res.data) {
                    setCurrentIotVersion(res)
                }
            }
        )
    }
    const GetIotConfig = () => {
        GetTCPConfigInfo().then(
            res => {
                if (res.data) {
                    let obj = {};
                    Object.keys(currentIotConfig).forEach(k => {
                        obj[k] = res.data[k];
                    });
                    console.log(obj)
                    form.setFieldsValue(obj);
                    setCurrentIotConfig(val => ({ ...val, ...obj }));

                }
            }
        )
    }
    const PingIot = ({ip, values}) => {
        PingIOTPlatform({
            ip: ip
        }).then(
            res => {
                if (res.code === 0) {
                    SaveIotConfig({
                        tcpAddress: values.TcpAddress,
                        iotAddress: values.IotAddress,
                        sslSafe: values.SSLSafe
                    })
                } else {
                    message.info("物联平台服务器连接异常!");
                }
            }
        )
    }
    const SaveIotConfig = (config) => {
        SaveTcpAddress(config).then(
            res => {
                if (res.code === 0) {
                    message.info('配置保存成功');
                }
            }
        )
    }


    return (
        <div className={styles.iot_container}>
            <Card title={`物联平台${currentIotVersion.data?`[${currentIotVersion.data}]`:""}`} style={{ width: "100%" }}>

                <Form
                    {...layout}
                    form={form}
                    name="basic"
                    initialValues={{ remember: true }}
                    onFinish={onFinish}
                    onFinishFailed={onFinishFailed}
                >
                    <div className={styles.section}>物联平台</div>
                    <Form.Item
                        label="服务器地址(平台)"
                        name="IotAddress"
                        rules={[{ required: true, pattern: new RegExp(/^(([1-9]?\d|1\d{2}|2[0-4]\d|25[0-5])\.){3}([1-9]?\d|1\d{2}|2[0-4]\d|25[0-5])$/, "g"),message: '请输入正确的IP例如:192.168.12.231' }]}

                    >
                        <Input />
                    </Form.Item>
                    <div className={styles.section}>EMQ</div>
                    <Form.Item
                        label="服务器地址(EMQ)"
                        name="TcpAddress"
                        rules={[{ required: true, message: '请输入域名(IP):端口,例如:192.168.19.102:8131' }]}


                    >
                        <Input />
                    </Form.Item>
                    <Form.Item
                        name="SSLSafe"
                        label="SSL(EMQ)"
                        rules={[{ required: true, message: '请选择是否!' }]}

                    >
                        <Select placeholder="请选择是否!">
                            <Option value="0">是</Option>
                            <Option value="1">否</Option>
                        </Select>
                    </Form.Item>
                    <Form.Item {...tailLayout}>
                        <Button type="primary" htmlType="submit" disabled={currentIotConfig.TcpAddress.length > 0 ? 0 : 1}>
                            保存连接
                        </Button>
                    </Form.Item>
                </Form>
            </Card>
        </div>
    )
}
export default IotConfig
